/*
  Tilt Controlled Bot.c

  XBee Circuit On ActivityBot
  http://learn.parallax.com/propeller-c-simple-protocols/full-duplex-serial

  The example code that's commented out is for use with the XBee Pro 3SB.
  If you try it, make sure to use the ATSH and ATSL addresses this module
  reports in the Tilt Controller's ATDH and ATDL commands. 

  IMPORTANT: The ATDL and ATDH in the commented code are for my XBee modules.
             You will have to get and use the replies from your own modules 
             for it to work in your applicaiton.   
*/

#include "simpletools.h"                          // Library header includes
#include "abdrive.h"
#include "xbeedev05.h"

xbee *xb;                                         // XBee fdserial identifier

int main()                                        // Main function
{
  xb = xbee_open(9, 8);                           // Start XBee connection

  print("\n");                                    // Room for display later
  
  /* For use with XBee Pro S3B */
  // xbee_cmd(xb, "+++");                            // Start command mode

  /* Use replies to this as ATDH and ATDL commands in Tilt Controller
     Command = ATSH Reply = 13A200 Command = ATSL Reply = 40C042A7 */
  // xbee_cmd(xb, "ATSH\r");
  // xbee_cmd(xb, "ATSL\r");

  /* Replies to ATSH and ATSL from Tilt Controller used in ATDH and ATDL here: */
  // xbee_cmd(xb, "ATDH 0013A200\r");
  // xbee_cmd(xb, "ATDL 40C04291\r");
  // xbee_cmd(xb, "ATCN \r");                        // Exit command mode

  while(1)                                        // Main loop
  {
    int count = 0, left, right;                   // Reps count and speed variables
    int x, y;                                     // Accelerometer x, y values 

    while(readChar(xb) != 's');                   // Wait for 's' (start packet).
    dscan(xb,"x%d y%d\n", &x, &y);                // Load incoming x & y values

    x = x * 3 / 2;                                // Multiply by 3/2 (faster)
    y = y * 3 / 2;                                // Multiply by 3/2

    if(x > 0) y = -y;                             // Swap L/R if reverse driving

    if(abs(x) > 8 || abs(y) > 8)                  // Tilted far enough from level?
    {
      left = -x + y;                              // Set left & right speeds
      right = -x - y;

      if(left > 128) left = 128;                  // Clamp max/min speeds
      if(left < -128) left = -128;
      if(right > 128) right = 128;
      if(right < -128) right = -128;
    }
    else                                          // Not far enough from level?
    {
      left = 0;                                   // Speeds to zero
      right = 0;
    }

    drive_speed(left, right);                     // Speeds control servo speeds

    if(count++ % 10 == 0)                         // Reps divisible by 10?
    {
      //Display HOME, x, y, left, and right
      print("%c x = %d, y = %d, left = %d, right = %d, %c,",
             HOME,   x,      y,      left,      right, CLREOL);
    }    
  }  
}