/*
  Tilt Controller.c

  MX2125 Circuit on Board
  http://learn.parallax.com/propeller-c-simple-devices/tilt-and-acceleration-mx2125

  XBee Circuit On Board
  http://learn.parallax.com/propeller-c-simple-protocols/full-duplex-serial

  The example code that's commented out is for use with the XBee Pro 3SB.
  If you try it, make sure to use the ATSH and ATSL addresses this module
  reports in the Tilt Controlled Bot's ATDH and ATDL commands.
  
  IMPORTANT: The ATDL and ATDH in the commented code are for my XBee modules.
             You will have to get and use the replies from your own modules 
             for it to work in your applicaiton.   
*/

#include "simpletools.h"                          // Library header includes
#include "mx2125.h"                               
#include "xbeedev05.h"

xbee *xb;                                         // XBee fdserial identifier

int main()                                        // Main function
{
  xb = xbee_open(9, 8);                           // Start XBee connection

  print("\n");                                    // Room for display later

  /* For use with XBee Pro S3B */
  // xbee_cmd(xb, "+++");                            // Start command mode

  /* Use replies to this as ATDH and ATDL commands in Tilt Controlled Bot.
     Command = ATSH Reply = 13A200 Command = ATSL Reply = 40C04291 */
  // xbee_cmd(xb, "ATSH\r");
  // xbee_cmd(xb, "ATSL\r");

  /* Replies to ATSH and ATSL from Tilt Controlled Bot used in ATDH and ATDL here: */
  // xbee_cmd(xb, "ATDH 0013A200\r");
  // xbee_cmd(xb, "ATDL 40C042A7\r");
  // xbee_cmd(xb, "ATCN \r");                        // Exit command mode

  int count = 0;                                  // Count for intermittent display

  while(1)                                        // Main loop
  {
    int x = mx_tilt(10);                          // X-axis tilt
    int y = mx_tilt(11);                          // Y-axis tilt

    writeChar(xb, 's');                           // Send 's' to start packet
    dprint(xb, "x%d y%d\n", x, y);                // Transmit x value y value \n

    pause(20);                                    // Wait 20 ms before repeat
    if(count++ % 10 == 0)                         // If remainder count / 10 is 0
      print("%c x = %d, y = %d, %c",              // Display x and y
             HOME, x, y, CLREOL);

  }  
}

