#include "xbeedev05.h"

int printEcho = 1;

xbee *xbee_open(int rxpin, int txpin)
{
  xbee *device = xbee_start(rxpin, txpin, 9600);
  return device;  
}


xbee *xbee_start(int rxpin, int txpin, int baudrate)
{
  int mode = 0;

  extern int binary_pst_dat_start[];

  xbee_st *xbptr;

  char* xbreply = (char*) malloc(10);
  memcpy(xbreply, "abcdefg", 8);
  char* bufptr = (char*) malloc(2*(FDSERIAL_BUFF_MASK+1));
  xbee* term = (xbee*) malloc(sizeof(xbee));
  memset(term, 0, sizeof(xbee));

  xbptr = (void*) malloc(sizeof(xbee_st));
  term->devst = xbptr;
  memset((char*)xbptr, 0, sizeof(xbee_st));

  if(rxpin == 31 && txpin == 30) {
    simpleterm_close();
  }

  /* required for terminal to work */
  term->txChar  =  fdserial_txChar;
  term->rxChar  =  fdserial_rxChar;

  xbptr->rx_pin = rxpin; /* recieve pin */
  xbptr->tx_pin = txpin; /* transmit pin */
  xbptr->mode   = mode;  /* interface mode */

  /* baud from clkfreq (cpu clock typically 80000000 for 5M*pll16x) */
  xbptr->ticks   = CLKFREQ/baudrate;

  xbptr->buffptr = bufptr; /* receive and transmit buffer */

  xbptr->xbreply = xbreply; /* receive and transmit buffer */

  /* now start the kernel */
#if defined(__PROPELLER_USE_XMM__)
  { unsigned int buffer[2048];
    memcpy(buffer, binary_pst_dat_start, 2048);
    term->cogid[0] = cognew(buffer, (void*)xbptr) + 1;
  }
#else
  term->cogid[0] = setStopCOGID(cognew((void*)binary_pst_dat_start, (void*)xbptr));
#endif
  waitcnt(CLKFREQ/2+CNT); // give cog chance to load
  return term;
}

/*
 * stop stops the cog running the native assembly driver 
 */
void xbee_close(xbee *term)
{
  int id = term->cogid[0];
  xbee_st* fdp = (xbee_st*) term->devst;

  while(fdserial_rxCheck(term) >= 0)
      ; // clear out queue by receiving all available 
  fdserial_txFlush(term);

  if(id > 0) cogstop(getStopCOGID(id));
  
  free((void*)fdp->buffptr);
  free((void*)fdp->xbreply);
  free((void*)fdp);
  free(term);
  term = 0;
}


void xbee_cmdPrint(int onOff)
{
  printEcho = onOff;
}

void xbee_baudRate(xbee *device, int baud)
{
  volatile xbee_st* xbp = (xbee_st*) device->devst;
  xbp->ticks   = CLKFREQ/baud;
}


char *xbee_cmd(xbee *device, char *cmd)
{
  volatile xbee_st* xbp = (xbee_st*) device->devst;

  int bytesMax = 10, msMax = 100;

  if(!strcmp(cmd, "+++"))
  {
    pause(1000);
    msMax = 2000;
  }

  if(printEcho)
  {
    putStr("Command = ");
    putStr(cmd);
  }

  int c = -1, n = 0;
  memset(xbp->xbreply, 0, bytesMax);
  writeStr(device, cmd);

  int tmax = (CLKFREQ/1000) * msMax;
  int tmark = CNT;

  while(1)
  {
    c = fdserial_rxCheck(device);
    if(c != -1)
    {
      xbp->xbreply[n++] = c;
    }
    if(CNT - tmark > tmax)
    {
      if(printEcho)
        putStr("Timeout error!\n");
      return 0;
    }
    if(c == '\r')
    {
      if(printEcho)
      {
        if(!strcmp(cmd, "+++")) putChar('\n');
        //print("Reply = %s", xbp->xbreply);
        putStr("Reply = ");
        putStr(xbp->xbreply);
      }
      return xbp->xbreply;
    }
  }
}






